@@ -65,6 +65,10 @@
 /* taken from gnome-terminal (terminal-screen.c) */
 #define SPAWN_TIMEOUT (30 * 1000 /* 30 s*/)
 
+/* minimum terminal dimensions */
+#define MIN_COLUMNS 4
+#define MIN_ROWS    1
+
 
 
 enum
@@ -1146,8 +1150,13 @@ terminal_screen_update_colors (TerminalScreen *screen)
           screen->has_random_bg_color = 0;
         }
     }
-  else
-    has_bg = gdk_rgba_parse (&screen->background_color, screen->custom_bg_color);
+  else if ((has_bg = gdk_rgba_parse (&bg, screen->custom_bg_color)))
+    {
+      /* preserve the alpha value which is responsible for transparency */
+      screen->background_color.red = bg.red;
+      screen->background_color.green = bg.green;
+      screen->background_color.blue = bg.blue;
+    }
 
   if (G_LIKELY (valid_palette))
     {
@@ -2138,8 +2147,8 @@ terminal_screen_set_window_geometry_hints (TerminalScreen *screen,
 
   hints.width_inc = char_width;
   hints.height_inc = char_height;
-  hints.min_width = hints.base_width + hints.width_inc * 4;
-  hints.min_height = hints.base_height + hints.height_inc * 2;
+  hints.min_width = hints.base_width + hints.width_inc * MIN_COLUMNS;
+  hints.min_height = hints.base_height + hints.height_inc * MIN_ROWS;
 
   gtk_window_set_geometry_hints (window,
 #if GTK_CHECK_VERSION (3, 19, 5)
